# NAACL Utils

A command line tool to help authors submit Docker images to the [NAACL Reproducibility Track](https://naacl2022-reproducibility-track.github.io/).

*Requires [Docker](https://www.docker.com/) and Python 3.7 or newer.*

Instructions for using the tool are in [the Dockerization tutorial](https://github.com/naacl2022-reproducibility-track/naacl2022-reproducibility-track.github.io/blob/main/_tutorial/04_submitting.md).
